# Python Functions

## Kraus 
::: quanestimation.Kraus

---

## Metrological resources
### Spin squeezing
::: quanestimation.SpinSqueezing
### Target time
::: quanestimation.TargetTime

---

## Quantum Cramér-Rao bounds
### Classical Fisher information matrix (CFIM)
::: quanestimation.CFIM
### Fisher information matrix (FIM)
::: quanestimation.FIM
### Fisher information (FI_Expt)
::: quanestimation.FI_Expt
### Symmetric logarithmic derivative (SLD)
::: quanestimation.SLD
### Right logarithmic derivative (RLD)
::: quanestimation.RLD
### Left logarithmic derivative (LLD)
::: quanestimation.LLD
### Quantum Fisher information matrix (QFIM)
::: quanestimation.QFIM
### Quantum Fisher information matrix with Kraus operators
::: quanestimation.QFIM_Kraus
### Quantum Fisher information matrix in Bloch representation
::: quanestimation.QFIM_Bloch
### Quantum Fisher information matrix with Gaussian states
::: quanestimation.QFIM_Gauss

---

## Holevo Cramér-Rao bound
::: quanestimation.HCRB

---

## Nagaoka-Hayashi bound
::: quanestimation.NHB

---

## Bayesian Cramér-Rao bounds
### Bayesian classical Fisher information matrix (BCFIM)
::: quanestimation.BCFIM
### Bayesian quantum Fisher information matrix (BQFIM)
::: quanestimation.BQFIM
### Bayesian Cramér-Rao bound (BCRB)
::: quanestimation.BCRB
### Bayesian quantum Cramér-Rao bound (BQCRB)
::: quanestimation.BQCRB
### Optimal biased bound (OBB)
::: quanestimation.OBB
### Van Trees bound (VTB)
::: quanestimation.VTB
### Quantum Van Trees bound (QVTB)
::: quanestimation.QVTB

---

## Quantum Ziv-Zakai bound
::: quanestimation.QZZB

---

## Bayesian estimation
### Maximum a posteriori probability (MAP)
::: quanestimation.Bayes
### Maximum likelihood estimation (MLE)
::: quanestimation.MLE
### Average Bayesian cost (BayesCost)
::: quanestimation.BayesCost
### Bayesian cost bound (BCB)
::: quanestimation.BCB

---

## Common utilities
### Bayes input
::: quanestimation.BayesInput
### SIC-POVM
::: quanestimation.SIC
### SU($N$) generators
::: quanestimation.suN_generator
